# MXCHIP ASCII Table Convertor

This tool is written by [Snow Yang](yangsw@mxchip.com) for MXCHIP IoT module developer to convert excel table to ASCII format.

The source code is at here: https://github.com/smartsnow/masciitable